﻿using System.Collections.ObjectModel;

namespace ThinkGeo.MapSuite.Core
{
    class HyperLinkAdornmentLayer : AdornmentLayer
    {
        private string linkString;
        private TextStyle linkTextStyle;
        private RectangleShape boundingBox;

        public HyperLinkAdornmentLayer()
            : this(null)
        { }

        public HyperLinkAdornmentLayer(string linkString)
            : this(linkString, new TextStyle())
        { }

        public HyperLinkAdornmentLayer(string linkString, TextStyle linkTextStyle)
            : base()
        {
            this.LinkString = linkString;
            Location = AdornmentLocation.LowerRight;
            this.linkTextStyle = linkTextStyle;
        }

        public string LinkString
        {
            get { return linkString; }
            set { linkString = value; }
        }

        public TextStyle LinkTextStyle
        {
            get { return linkTextStyle; }
            set { linkTextStyle = value; }
        }

        public override bool HasBoundingBox
        {
            get
            {
                return true;
            }
        }

        protected override void DrawCore(GeoCanvas canvas, Collection<SimpleCandidate> labelsInAllLayers)
        {
            if (IsVisible)
            {
                if (!string.IsNullOrEmpty(linkString))
                {
                    DrawingRectangleF rectangleF = canvas.MeasureText(linkString, linkTextStyle.Font);
                    float imageWidth = rectangleF.Width;
                    float imageHeight = rectangleF.Height;
                    ScreenPointF upperLeftPoint = GetDrawingLocation(canvas, imageWidth, imageHeight);
                    ScreenPointF lowerRightPoint = new ScreenPointF(upperLeftPoint.X + imageWidth, upperLeftPoint.Y + imageHeight);
                    ScreenPointF[] box = new ScreenPointF[] { new ScreenPointF((upperLeftPoint.X + lowerRightPoint.X) / 2, (upperLeftPoint.Y + lowerRightPoint.Y) / 2) };
                    canvas.DrawText(linkString, linkTextStyle.Font, linkTextStyle.TextSolidBrush, linkTextStyle.HaloPen, box, DrawingLevel.LabelLevel, 0, 0, 0);

                    PointShape upperLeft = ExtentHelper.ToWorldCoordinate(canvas.CurrentWorldExtent, upperLeftPoint, canvas.Width, canvas.Height);
                    PointShape lowerRight = ExtentHelper.ToWorldCoordinate(canvas.CurrentWorldExtent, lowerRightPoint, canvas.Width, canvas.Height);
                    boundingBox = new RectangleShape(upperLeft, lowerRight);

                }
            }
        }

        protected override RectangleShape GetBoundingBoxCore()
        {
            return boundingBox;
        }
    }
}
