﻿using System;
using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;
using System.Collections.ObjectModel;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Media.Effects;

namespace Post11592
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private HyperLinkAdornmentLayer linkAdornmentLayer;
        private ExLogoAdornmentLayer logoLinkLayer;

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;

            ShapeFileFeatureLayer shapeFileLayer = new ShapeFileFeatureLayer(@"..\..\Data\Countries02.shp");
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.State1;
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            linkAdornmentLayer = new HyperLinkAdornmentLayer("Link to ThinkGeo");
            linkAdornmentLayer.XOffsetInPixel = -30;
            linkAdornmentLayer.Location = AdornmentLocation.UpperCenter;
            linkAdornmentLayer.LinkTextStyle.Font = new GeoFont("Arial", 15);
            linkAdornmentLayer.LinkTextStyle.TextSolidBrush = new GeoSolidBrush(GeoColor.SimpleColors.Blue);
            
            logoLinkLayer = new ExLogoAdornmentLayer(new GeoImage(@"..\..\Data\Compass.png"));
            logoLinkLayer.Location = AdornmentLocation.UpperCenter;
            logoLinkLayer.XOffsetInPixel = -90;

            LayerOverlay overlay = new LayerOverlay();
            overlay.Layers.Add("WorldLayer", shapeFileLayer);

            wpfMap1.AdornmentOverlay.Layers.Add(linkAdornmentLayer);
            wpfMap1.AdornmentOverlay.Layers.Add(logoLinkLayer);
            wpfMap1.MapClick += new EventHandler<MapClickWpfMapEventArgs>(wpfMap1_MapClick);

            shapeFileLayer.Open();
            wpfMap1.CurrentExtent = shapeFileLayer.GetBoundingBox();
            shapeFileLayer.Close();

            wpfMap1.Overlays.Add("WorldOverlay", overlay);
            wpfMap1.Refresh();
        }

        void wpfMap1_MapClick(object sender, MapClickWpfMapEventArgs e)
        {
            if (linkAdornmentLayer != null && linkAdornmentLayer.GetBoundingBox().Contains(e.WorldLocation))
            {
                MessageBox.Show("linkAdornmentLayer clicked!");
            }
            if (logoLinkLayer != null && logoLinkLayer.GetBoundingBox().Contains(e.WorldLocation))
            {
                MessageBox.Show("logoLinkLayer clicked!");
            }
        }
    }
}
